import os
import SimpleITK as sitk


class Dcm2Nifti(object):

    def __init__(self):
        self._input_dicom_file_path = None
        self._output_dir = None
        self._output_file_path = None
        self._shape = None
        self._spacing = None
        self._origin = None
        self._direction = None
        self._overwrite_output = False

    def set_input_dicom_file_path(self, file_path):
        self._input_dicom_file_path = file_path

    def set_output_dir(self, output_dir):
        self._output_dir = output_dir

    def set_overwrite_output(self, value):
        self._overwrite_output = value

    def get_output_file_path(self):
        return self._output_file_path

    def execute(self):
        os.makedirs(self._output_dir, exist_ok=True)
        reader = sitk.ImageFileReader()
        reader.SetFileName(self._input_dicom_file_path)
        reader.SetImageIO('GDCMImageIO')
        image = reader.Execute()
        file_name = os.path.split(self._input_dicom_file_path)
        file_name = file_name[1]
        file_name = os.path.splitext(file_name)
        file_name = file_name[0]
        file_name = '{}.nii.gz'.format(file_name)
        file_path = os.path.join(self._output_dir, file_name)
        try:
            os.stat(file_path)
            if not self._overwrite_output:
                print('Error: file {} already exists!'.format(file_path))
                return
        except FileNotFoundError:
            pass
        self._output_file_path = file_path
        writer = sitk.ImageFileWriter()
        writer.SetFileName(self._output_file_path)
        writer.SetImageIO('NiftiImageIO')
        writer.Execute(image)
        print('Written {}'.format(self._output_file_path))


if __name__ == '__main__':
    node = Dcm2Nifti()
    node.set_input_dicom_file_path('/Volumes/USB_SECURE1/data/radiomics/projects/004_ovarium/data/test/IM_1.dcm')
    node.set_output_dir('/Volumes/USB_SECURE1/data/radiomics/projects/004_ovarium/data/test/out')
    node.set_overwrite_output(True)
    node.execute()



import os
import cmd2
import pydicom

from pydicom.tag import Tag
from pydicom._dicom_dict import DicomDictionary

from barbell2.lib import BasicShell


INTRO = """
Welcome to the DICOM Explorer!
------------------------------
This tool allows you to explore lots of DICOM files at the same time. Type 'help' to view a short list of
commands. Type 'help <command>' to view details about a given command.
"""

PROMPT = '(shell) '


def is_dicom(file_path):
    if not os.path.isfile(file_path):
        return False
    try:
        with open(file_path, "rb") as f:
            return f.read(132).decode("ASCII")[-4:] == "DICM"
    except:
        return False


class DicomExplorerShell(BasicShell):

    def __init__(self):
        super(DicomExplorerShell, self).__init__()
        self.intro = INTRO
        self.prompt = PROMPT
        self.debug = True

    # LOADING FILES AND DIRECTORIES

    def do_load_file(self, file_path):
        """
        Usage: load_file <file name or path>
        Load a single DICOM file. If only the name is provided, it assumed that the file is located in the
        current directory.
        """
        if not os.path.isfile(file_path):
            file_path = os.path.join(self.current_dir, file_path)
        if not is_dicom(file_path):
            self.poutput('File is not DICOM')
            return
        self.poutput('Loading...')
        self.result_manager.add_result_data([file_path])
        self.poutput('Loading done')

    def do_load_dir(self, dir_path):
        """
        Usage: load_dir <dir name or path>
        Load (recursively) all DICOM files in the given directory. If only the directory name is given, it is
        assumed that the directory is located in the current directory.
        """
        if not os.path.isdir(dir_path):
            dir_path = os.path.join(self.current_dir, dir_path)
        self.poutput('Loading {}...'.format(dir_path))
        data = []
        for root, dirs, files in os.walk(dir_path):
            for f in files:
                if not f.startswith('._'):
                    f = os.path.join(root, f)
                    if is_dicom(f):
                        data.append(f)
        self.result_manager.add_result_data(data)
        self.poutput('Loading done')

    def do_show_files(self, _):
        """
        Usage: show_files
        Show all files loaded in the current result set. If you want to show files from another result set
        select it first using the set_current_result command.
        """
        files = self.result_manager.get_current_result_data()
        for f in files:
            self.poutput(f)
        self.poutput(len(files))

    def do_lookup_tag_in_dict(self, tag_name):
        """
        Usage: lookup_tag_in_dict <tag name>
        Lookup tag <tag name> in the DICOM dictionary. You can specify only parts of a tag name, e.g.,
        "Transmit" will return multiple dictionary entries containing the word "Transmit" (like Transmit
        Coil Name). Being able to lookup tags comes in handy when you search for them in DICOM files.
        """
        for key, value in DicomDictionary.items():
            output = '{}: {}'.format(key, value)
            if tag_name == '':
                self.poutput(output)
            else:
                for item in value:
                    if tag_name in item:
                        self.poutput(output)

    def do_find_tag(self, tag_name):
        """
        Usage: find_tag <tag name>
        Find tag <tag name> in the currently loaded DICOM files.
        """
        files = self.result_manager.get_current_result_data()
        for f in files:
            p = pydicom.read_file(f)
            for tag in p.keys():
                if tag in list(DicomDictionary.keys()):
                    if tag_name == DicomDictionary[tag][4]:
                        self.poutput('{}: {}'.format(f, p[tag].value))
                        break
                else:
                    self.poutput('Warning: tag {} cannot be found in the DICOM dictionary'.format(tag))

    def do_dump_file(self, file_name):
        """
        Usage: dump_file <file name>
        Dump DICOM header of <file name>. If <file name> is left empty, this function will search for
        all file paths that contain the given file name. If only one is encountered, the DICOM header will
        be displayed. If multiple files are encountered, a list of those files is displayed so that you can
        select a specific one (with its full path).
        """
        files = self.result_manager.get_current_result_data()
        count = 0
        counted_files = []
        for f in files:
            if file_name in f:
                count += 1
                counted_files.append(f)
        if count == 0:
            if os.path.isfile(file_name):
                p = pydicom.read_file(file_name)
                self.poutput(p)
            else:
                self.poutput('Could not find file {}'.format(file_name))
        elif count == 1:
            p = pydicom.read_file(counted_files[0])
            self.poutput(p)
        elif count > 1:
            self.poutput('Found multiple files with same name:')
            for f in counted_files:
                self.poutput(f)
            self.poutput('Please select full file path of file you want and repeat this command')


if __name__ == '__main__':
    import sys
    shell = DicomExplorerShell()
    sys.exit(shell.cmdloop())



import os
import argparse

parser = argparse.ArgumentParser(description=__doc__)
parser.add_argument('root_dir', help='Root folder containing collection folders')
parser.add_argument('output_dir', help='Output folder where files train.h5, validation.h5 and test.h5 will be written')
parser.add_argument('--training', help='Comma-separated list of collection names for training')
parser.add_argument('--validation', help='Comma-separated list of collection names for validation')
parser.add_argument('--test', help='Comma-separated list of collection names for validation')
args = parser.parse_args()


def check_collections(root_dir, collections):
    collection_list = [x.strip() for x in collections.split(',')]
    for collection in collection_list:
        if not os.path.isdir(os.path.join(root_dir, collection)):
            raise RuntimeError('Collection directory "{}" for does not exist'.format(collection))


def run():

    # Verify that root folder exists and is not empty
    if not os.path.isdir(args.root_dir):
        raise RuntimeError('Root directory "{}" does not exist'.format(args.root_dir))
    if len(os.listdir(args.root_dir)) == 0:
        raise RuntimeError('Root directory "{}" is empty'.format(args.root_dir))

    # Verify that output folder does not exist
    if os.path.isdir(args.output_dir):
        raise RuntimeError('Output directory "{}" exists. Please delete it'.format(args.output_dir))

    # Verify that training, validation and test collections exist and are not empty
    if args.training is not None:
        check_collections(args.root_dir, args.training)
    if args.validation is not None:
        check_collections(args.root_dir, args.validation)
    if args.test is not None:
        check_collections(args.root_dir, args.test)

    # Create training H5

    # Create validation H5

    # Create test H5


if __name__ == '__main__':
    run()



#!/usr/bin/env python

import os

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['pytest', 'cmd2', 'gnureadline', 'pydicom', 'pandas', 'numpy', 'SimpleITK']

setup_requirements = []

test_requirements = []

setup(
    author="Ralph Brecheisen",
    author_email='ralph.brecheisen@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Collection of Python libraries and tools",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='barbell2',
    name='barbell2',
    packages=find_packages(include=['barbell2', 'barbell2.*']),
    setup_requires=setup_requirements,
    entry_points="""
        [console_scripts]
        barbell2=barbell2.__main__:main
    """,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/rbrecheisen/barbell2',
    version=os.environ['VERSION'],
    zip_safe=False,
)
